@@ -77,7 +77,7 @@ struct request {		/* this is and may not used */
 #include <scsitransp.h>
 
 #include "byteorder.h"
-#include "readall.h"
+#include "read2448.h"
 #include "interface.h"
 #include "global.h"
 #include "scsi_cmds.h"
@@ -256,7 +256,7 @@ static void Check_interface_for_device( struct stat *statstruct, char *pdev_name
 	 exit(1);
        }
 #endif
-       if (global.nsectors > scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER)
+       if (global.nsectors > (unsigned)scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER)
          global.nsectors = scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER;
        break;
 #if defined (__linux__)
@@ -364,7 +364,7 @@ static int OpenCdRom ( char *pdev_name )
         fprintf(stderr, "You can also define the default device in the Makefile.\n");
         exit(1);
       }
-      if (global.nsectors > scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER)
+      if (global.nsectors > (unsigned)scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER)
         global.nsectors = scsi_bufsize(100*1024*1024)/CD_FRAMESIZE_RAWER;
       if (global.overlap >= global.nsectors)
         global.overlap = global.nsectors-1;
